<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * block_wcln_progress block.
 *
 * @package   block_wcln_progress
 * @copyright 2020 onwards WCLN
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
defined('MOODLE_INTERNAL') || die();
require_once($CFG->dirroot . '/blocks/wcln_progress/lib.php');
class block_wcln_progress extends block_list {
    public function init() {
        $this->title = wcln_progress::_s('pluginname');
    }

    public function applicable_formats() {
        global $USER;
        if (is_siteadmin($USER->id) || has_capability('block/wcln_progress:myaddinstance', context_system::instance())) {
            return array('site' => true, 'my' => true, 'course-view' => true);
        } else {
            return array('site' => false, 'my' => false, 'course-view' => true);
        }
    }
    public function has_config() {
        return true;
    }
    /**
     * Disable multiple instances of this block
     * @return bool Returns false
     */
    public function instance_allow_multiple() {
        return false;
    }
    public function get_content() {
        global $USER, $COURSE, $OUTPUT;

        if ($this->content !== null) {
            return $this->content;
        }

        $this->content = new stdClass;
        $this->content->items = array();
        $this->content->icons = array();
        $this->content->footer = '';

        $context = context_course::instance($COURSE->id);

        $permission = has_capability('block/wcln_progress:cansend', $context);

        $cansend = ($permission or !empty($config['allowstudents']));
        $iconclass = array('class' => 'icon');
        $cparam = array('courseid' => $COURSE->id);
        if ($cansend && $COURSE->id != SITEID) {
            $sendemailstr = wcln_progress::_s('composenew');
            $icon = $OUTPUT->pix_icon('t/email', $sendemailstr, 'moodle', $iconclass);
            if (isset($this->config->groups)) {
                if ($this->config->groups == '1') {
                    $cparam2 = array('courseid' => $COURSE->id, 'groups' => 1);
                } else {
                    $cparam2 = array('courseid' => $COURSE->id, 'groups' => 0);
                }
            } else {
                $cparam2 = array('courseid' => $COURSE->id, 'groups' => 0);
            }
            $sendemail = html_writer::link(
                new moodle_url('/blocks/wcln_progress/email.php', $cparam2),
                $icon.$sendemailstr
            );
            $this->content->items[] = $sendemail;

            $historystr = wcln_progress::_s('history');
            $icon = $OUTPUT->pix_icon('i/settings', $historystr, 'moodle', $iconclass);
            $history = html_writer::link(
                new moodle_url('/blocks/wcln_progress/emaillog.php', $cparam),
                $icon.$historystr
            );
            $this->content->items[] = $history;
        }

        if ((has_capability('block/wcln_progress:myaddinstance', context_system::instance())
            || is_siteadmin($USER->id)) && $COURSE->id == SITEID) {
            $sendadminemailstr = wcln_progress::_s('sendadmin');
            $icon = $OUTPUT->pix_icon('t/email', $sendadminemailstr, 'moodle', $iconclass);
            $sendadminemail = html_writer::link(
                new moodle_url('/blocks/wcln_progress/admin_email.php'),
                $icon.$sendadminemailstr
            );
            $this->content->items[] = $sendadminemail;
        }
        if (is_siteadmin($USER->id) && $COURSE->id == SITEID) {
            $historystr = wcln_progress::_s('history');
            $icon = $OUTPUT->pix_icon('i/settings', $historystr, 'moodle', $iconclass);
            $history = html_writer::link(
                new moodle_url('/blocks/wcln_progress/emaillog.php', $cparam),
                $icon.$historystr
            );
            $this->content->items[] = $history;
        }
        return $this->content;
    }
}
